@@ -3,8 +3,8 @@ import html
 import os
 # local files
 from . import warning
-from .placeholder_data import Placeholder
-from .html_tag_parser import create_html_opening_tag, ParsedHtmlTag
+from .placeholder_data import Placeholder, InputType
+from .html_tag_parser import ParsedHtmlTag
 from .input_tag_handler import InputTagHandler
 
 
@@ -50,7 +50,8 @@ class StaticReplacer:
         replacements and hope it does not cause any errors.
         """
         for placeholder in self.placeholders.values():
-            text = text.replace(f"x{placeholder.name}x", html.escape(placeholder.default_value))
+            placeholder_value = get_default_placeholder_value(placeholder)
+            text = text.replace(f"x{placeholder.name}x", html.escape(placeholder_value))
         return text
 
     def _disable_placeholder_input_fields(self, path: str, text: str) -> str:
@@ -64,20 +65,47 @@ def create_static_input_field_replacer(placeholders: dict[str,Placeholder]) -> I
     def static_replacer_input_tag_modifier(handler, tag: str, parsed: ParsedHtmlTag) -> str:
         placeholder_name = parsed.attributes.get("data-input-for")
         if placeholder_name:
-            attrs = dict(parsed.attributes)
-
-            # Print a warning if the placeholder does not exist
             if placeholder_name not in placeholders:
+                # Print a warning if the placeholder does not exist
                 warning(f"{handler.location} (static replacer) - Input element is linked to non-existent variable '{placeholder_name}'. Is this a typo or did you forget to set a default value for it?")
-                attrs["value"] = f"Undefined variable {placeholder_name}"
+                return f'<input value="Undefined variable {html.escape(placeholder_name)}" disabled>'
             else:
-                attrs["value"] = placeholders[placeholder_name].default_value
-            
-            # Disable the input elements
-            attrs["disabled"] = "1"
-
-            return create_html_opening_tag(parsed.tag, attrs)
+                # Properly handle the different input element types
+                return create_input_html(placeholders[placeholder_name])
         else:
             return tag
     
     return InputTagHandler(static_replacer_input_tag_modifier, False)
+
+
+def get_default_placeholder_value(placeholder: Placeholder) -> str:
+    if placeholder.input_type == InputType.Checkbox:
+        default_value = placeholder.default_value or "unchecked"
+        return placeholder.values[default_value]
+    elif placeholder.input_type == InputType.Dropdown:
+        if placeholder.default_value:
+            return placeholder.values[placeholder.default_value]
+        else:
+            return list(placeholder.values.values())[0]
+    elif placeholder.input_type == InputType.Field:
+        return placeholder.default_value
+    else:
+        raise Exception(f"Unknown input type: {placeholder.input_type}")
+
+
+def create_input_html(placeholder: Placeholder) -> str:
+    if placeholder.input_type == InputType.Checkbox:
+        checked_by_default = placeholder.default_value == "checked"
+        checked_attribute = " checked" if checked_by_default else ""
+        return f'<input type="checkbox" disabled{checked_attribute}>'
+    elif placeholder.input_type == InputType.Dropdown:
+        # We only show the name of the default option
+        if placeholder.default_value:
+            default_value = placeholder.default_value
+        else:
+            default_value = list(placeholder.values.keys())[0]
+        return f'<select disabled><option>{html.escape(default_value)}</option></select>'
+    elif placeholder.input_type == InputType.Field:
+        return f'<input value="{html.escape(placeholder.default_value)}" disabled>'
+    else:
+        raise Exception(f"Unknown input type: {placeholder.input_type}")
